@@ -137,7 +137,7 @@ class Workflow(models.Model, metaclass=WorkflowBase):
                 if isinstance(node, BaseCreateView):
                     route = "{name}/".format(name=name)
                 else:
-                    route = "{name}/<pk>/".format(name=name)
+                    route = "{name}/<int:pk>/".format(name=name)
                 urls.append(
                     path(
                         route + node.path,
@@ -147,12 +147,12 @@ class Workflow(models.Model, metaclass=WorkflowBase):
                 )
         if cls.detail_view:
             urls.append(
-                path("<pk>/", cls.detail_view.as_view(model=cls), name="detail")
+                path("<int:pk>/", cls.detail_view.as_view(model=cls), name="detail")
             )
         if cls.override_view:
             urls.append(
                 path(
-                    "<pk>/override",
+                    "<int:pk>/override",
                     cls.override_view.as_view(model=cls),
                     name="override",
                 )
@@ -571,7 +571,7 @@ class Task(models.Model):
         for node in next_nodes:
             try:
                 # Some nodes – like Join – implement their own method to create new tasks.
-                task = node.create_task(self.workflow)
+                task = node.create_task(self.workflow, self)
             except AttributeError:
                 task = self.workflow.task_set.create(
                     name=node.name, type=node.type, workflow=self.workflow
